darkhistory.physics.nH — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.nH

`darkhistory.physics.` `nH` = 1.897518207795223e-07

  Atomic hydrogen number density in cm-3.

#### Previous topic

darkhistory.physics.nB

#### Next topic

darkhistory.physics.nHe

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.